[Mesa-dev] [PATCH 09/23] anv: Annotate entrypoint table with index and func name

Chad Versace chadversary at chromium.org
Sat Sep 2 08:17:32 UTC 2017


This helps when debugging a broken entrypoint table.
---
 src/intel/vulkan/anv_entrypoints_gen.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/intel/vulkan/anv_entrypoints_gen.py b/src/intel/vulkan/anv_entrypoints_gen.py
index 82221ef94bd..983be09a39b 100644
--- a/src/intel/vulkan/anv_entrypoints_gen.py
+++ b/src/intel/vulkan/anv_entrypoints_gen.py
@@ -120,8 +120,8 @@ TEMPLATE_C = Template(textwrap.dedent(u"""\
     ;
 
     static const struct anv_entrypoint entrypoints[] = {
-    % for _, _, _, num, h, _ in entrypoints:
-        { ${offsets[num]}, ${'{:0=#8x}'.format(h)} },
+    % for _, name, _, num, h, _ in entrypoints:
+        [${num}] = { ${offsets[num]}, ${'{:0=#8x}'.format(h)} }, /* vk${name} */
     % endfor
     };
 
-- 
2.13.5



More information about the mesa-dev mailing list